@@ -9,12 +9,12 @@ use {
 pub struct IncrementUsagesCtx<'info> {
     token_manager: Box<Account<'info, TokenManager>>,
 
-    #[account(mut, constraint = use_invalidator.usages + num_usages <= use_invalidator.max_usages @ ErrorCode::InvalidUsages)]
+    #[account(mut, constraint = use_invalidator.max_usages == None || use_invalidator.usages + num_usages <= use_invalidator.max_usages.unwrap() @ ErrorCode::InsufficientUsages)]
     use_invalidator: Box<Account<'info, UseInvalidator>>,
 
-    #[account(mut)]
-    payer: Signer<'info>,
-    system_program: Program<'info, System>,
+    // TODO maybe add use authority to this state
+    // #[account(constraint = user.key() == token_manager.recipient_token_account.owner)]
+    user: Signer<'info>,
 }
 
 pub fn handler(ctx: Context<IncrementUsagesCtx>, num_usages: u64) -> ProgramResult {
